@@ -9,6 +9,7 @@ from pmb.helpers import logging
 from pmb.helpers.exceptions import NonBugError
 import os
 from pathlib import Path
+import platform
 import re
 import signal
 import shlex
@@ -240,27 +241,50 @@ def command_qemu(
     command += ["-netdev", f"user,id=net,hostfwd=tcp:127.0.0.1:{port_ssh}-:22"]
     command += ["-device", "virtio-net-pci,netdev=net"]
 
-    if arch == Arch.x86_64:
-        if args.qemu_display != "none":
-            command += ["-device", "virtio-vga-gl"]
-    elif arch == Arch.aarch64:
-        command += ["-M", "virt"]
-        command += ["-cpu", "cortex-a57"]
-        command += ["-device", "virtio-gpu-pci"]
-    elif arch == Arch.riscv64:
-        command += ["-M", "virt"]
-        command += ["-device", "virtio-gpu-pci"]
-    elif arch == Arch.ppc64le:
-        command += ["-M", "pseries"]
-        command += ["-device", "virtio-gpu-pci"]
-    else:
+    # Check that arch is supported by pmb qemu
+    if arch not in [Arch.x86_64, Arch.aarch64, Arch.riscv64, Arch.ppc64le]:
         raise RuntimeError(f"Architecture {arch} not supported by this command yet.")
 
+    # Apply arch-specific qemu config
+    match arch:
+        case Arch.aarch64:
+            command += ["-M", "virt"]
+            command += ["-cpu", "cortex-a57"]
+        case Arch.riscv64:
+            command += ["-M", "virt"]
+        case Arch.ppc64le:
+            command += ["-M", "pseries"]
+
+    # Configure display
+    if args.qemu_display != "none":
+        match arch:
+            case Arch.x86_64:
+                command += ["-device", "virtio-vga-gl"]
+            case Arch.aarch64:
+                command += ["-device", "virtio-gpu-gl"]
+            case Arch.riscv64:
+                command += ["-device", "virtio-gpu-pci"]
+            case Arch.ppc64le:
+                command += ["-device", "virtio-gpu-pci"]
+            case _:
+                # default to 2D-only backend
+                command += ["-device", "virtio-gpu"]
+
     if args.efi:
-        command += [
-            "-drive",
-            f"if=pflash,format=raw,readonly=on,file={chroot_native.path}/usr/share/OVMF/OVMF.fd",
-        ]
+        host_arch = platform.machine().lower()
+        match host_arch:
+            case "aarch64":
+                command += [
+                    "-drive",
+                    f"if=pflash,format=raw,readonly=on,file={chroot_native.path}/usr/share/AAVMF/AAVMF_CODE.fd",
+                ]
+            case "amd64":
+                command += [
+                    "-drive",
+                    f"if=pflash,format=raw,readonly=on,file={chroot_native.path}/usr/share/OVMF/OVMF.fd",
+                ]
+            case _:
+                raise RuntimeError(f"Architecture {host_arch} not configured for EFI support.")
 
     # Kernel Virtual Machine (KVM) support
     native = pmb.parse.deviceinfo().arch.is_native()
@@ -349,6 +373,7 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
         "qemu-hw-display-virtio-gpu",
         "qemu-hw-display-virtio-gpu-gl",
         "qemu-hw-display-virtio-gpu-pci",
+        "qemu-hw-display-virtio-gpu-pci-gl",
         "qemu-hw-display-virtio-vga",
         "qemu-hw-display-virtio-vga-gl",
         "qemu-system-" + arch.qemu(),
@@ -366,7 +391,14 @@ def install_depends(args: PmbArgs, arch: Arch) -> None:
         depends.remove("qemu-ui-opengl")
 
     if args.efi:
-        depends.append("ovmf")
+        host_arch = platform.machine().lower()
+        match host_arch:
+            case "aarch64":
+                depends.append("aavmf")
+            case "amd64":
+                depends.append("ovmf")
+            case _:
+                raise RuntimeError(f"Architecture {host_arch} not configured for EFI support.")
 
     chroot = Chroot.native()
     pmb.chroot.init(chroot)
@@ -380,7 +412,7 @@ def run(args: PmbArgs) -> None:
     config = get_context().config
     device = config.device
     if not device.startswith("qemu-"):
-        raise RuntimeError(
+        raise NonBugError(
             "'pmbootstrap qemu' can be only used with one of "
             "the QEMU device packages. Run 'pmbootstrap init' "
             "and select the 'qemu' vendor."
